@@ -60,16 +60,14 @@ void ActionConfigWidget::addWidgets(QList<QPair<QString, QWidget*> > configMap)
 
         // allow left-aligning checkboxes without treating them as section header
         } else if (line.first == QLatin1String("NONE")) {
-            m_gridLayout->addItem(new QSpacerItem(50 ,3), row, 0);
-            m_gridLayout->addWidget(line.second, row, 1, Qt::AlignRight);
-            //m_gridLayout->addWidget(line.second, row, 1, 2, 1, Qt::AlignRight);
-
+            m_gridLayout->addItem(new QSpacerItem(50, 3), row, 0);
+            m_gridLayout->addWidget(line.second, row, 1, 1, 2);
         } else {
             // connect enabled / disabled
             QLabel* label = new QLabel(this);
             label->setText(line.first);
 
-            m_gridLayout->addItem(new QSpacerItem(50 ,3), row, 0);
+            m_gridLayout->addItem(new QSpacerItem(50, 3), row, 0);
             m_gridLayout->addWidget(label, row, 1, Qt::AlignRight);
             m_gridLayout->addWidget(line.second, row, 2);
 
